==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/headerview.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef HEADERVIEW_H
#define HEADERVIEW_H

#include <QHeaderView>
class Config;
class MPDSongModel;
class MPDSongView;
class QMenu;

class HeaderView : public QHeaderView {
	Q_OBJECT
public:
	enum Column { TRACK = 0,
	              TITLE = 1,
	              ARTIST = 2,
	              ALBUM = 3,
	              GENRE = 4,
	              COMPOSER = 5,
	              DATE = 6,
	              LENGTH = 7,
	              URL = 8,
	              FILENAME = 9,
	              PLAYLISTPOS = 10
	            };
	enum View { PLAYLISTVIEW = 10,
	            SONGVIEW = 11,
	            DIRECTORYVIEW = 12,
	            FILEVIEW = 13,
	            PLAYLISTSVIEW = 14,
	            PLAYLISTSCONTENTVIEW = 15,
	            RADIOVIEW = 16
	          };

protected:
	bool m_autoResize;
	bool m_forceAutoResize;
	Config *m_config;
	View m_view;
	MPDSongModel *m_model;
	MPDSongView *m_treeView;
	QMenu *m_menu;
	QList<Column> m_columns;
	void contextMenuEvent(QContextMenuEvent *);
	void mouseReleaseEvent(QMouseEvent *);
	QString viewName();
	void paintEvent(QPaintEvent *);

public:
	HeaderView(QWidget *, View, bool = false);
	void setDefaultState();

protected slots:
	void autoResizeChanged(bool);
	void actionTriggered();
	void save();

public:
	View view();
	void restore();
	QList<Column> columns();
	QList<Column> visibleColumns();
};

#endif

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/headerview.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef HEADERVIEW_H
#define HEADERVIEW_H

#include <QHeaderView>

class HeaderView : public QHeaderView {
	Q_OBJECT
public:
	enum Column { TRACK = 0,
	              TITLE = 1,
	              ARTIST = 2,
	              ALBUM = 3,
	              GENRE = 4,
	              COMPOSER = 5,
	              DATE = 6,
	              LENGTH = 7,
	              URL = 8,
	              FILENAME = 9
	            };
	enum View { SONGVIEW = 11,
	            DIRECTORYVIEW = 12,
	            FILEVIEW = 13,
	            PLAYLISTSVIEW = 14,
	            PLAYLISTSCONTENTVIEW = 15,
	            RADIOVIEW = 16
	          };

private:
	View m_view;
	class Config *m_config;
	QMenu *m_menu;
	QList<Column> m_columns;
	void contextMenuEvent(QContextMenuEvent *);
	void mouseReleaseEvent(QMouseEvent *);
	QString viewName() const;

public:
	HeaderView(QWidget *, View);
	void restore();
	QList<Column> columns() const;
	QString columnName(Column) const;

private slots:
	void autoResizeChanged(bool);
	void actionTriggered();
	void save();
};

#endif
